@@ -1,47 +1,33 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Dominik Haumann <dhaumann kde org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2010-2018 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "katescriptaction.h"
-#include "katecommandlinescript.h"
-#include "katescriptmanager.h"
-#include "kateview.h"
+#include "kateabstractinputmode.h"
+#include "katecmd.h"
 #include "katedocument.h"
 #include "kateglobal.h"
-#include "kateviewhelpers.h"
 #include "katepartdebug.h"
-#include "katecmd.h"
-#include "kateabstractinputmode.h"
+#include "katescriptmanager.h"
+#include "kateview.h"
+#include "kateviewhelpers.h"
 
 #include <QJsonObject>
 
-#include <KXMLGUIFactory>
 #include <KActionCollection>
 #include <KLocalizedString>
+#include <KXMLGUIFactory>
 
-//BEGIN KateScriptAction
+// BEGIN KateScriptAction
 KateScriptAction::KateScriptAction(const QString &cmd, const QJsonObject &action, KTextEditor::ViewPrivate *view)
-    : QAction(i18nc("Script command name", action.value(QLatin1String("name")).toString().toUtf8().data()), view)
+    : QAction(i18nc("Script command name", action.value(QStringLiteral("name")).toString().toUtf8().data()), view)
     , m_view(view)
     , m_command(cmd)
-    , m_interactive(action.value(QLatin1String("interactive")).toBool())
+    , m_interactive(action.value(QStringLiteral("interactive")).toBool())
 {
-    const QString icon = action.value(QLatin1String("icon")).toString();
+    const QString icon = action.value(QStringLiteral("icon")).toString();
     if (!icon.isEmpty()) {
         setIcon(QIcon::fromTheme(icon));
     }
@@ -65,18 +51,18 @@ void KateScriptAction::exec()
         }
     }
 }
-//END KateScriptAction
+// END KateScriptAction
 
-//BEGIN KateScriptActionMenu
+// BEGIN KateScriptActionMenu
 KateScriptActionMenu::KateScriptActionMenu(KTextEditor::ViewPrivate *view, const QString &text)
-    : KActionMenu(QIcon::fromTheme(QLatin1String("code-context")), text, view)
+    : KActionMenu(QIcon::fromTheme(QStringLiteral("code-context")), text, view)
     , m_view(view)
 {
     repopulate();
+    setDelayed(false);
 
     // on script-reload signal, repopulate script menu
-    connect(KTextEditor::EditorPrivate::self()->scriptManager(), SIGNAL(reloaded()),
-            this, SLOT(repopulate()));
+    connect(KTextEditor::EditorPrivate::self()->scriptManager(), SIGNAL(reloaded()), this, SLOT(repopulate()));
 }
 
 KateScriptActionMenu::~KateScriptActionMenu()
@@ -107,30 +93,21 @@ void KateScriptActionMenu::repopulate()
     cleanup();
 
     // now add all command line script commands
-    QVector<KateCommandLineScript *> scripts =
-        KTextEditor::EditorPrivate::self()->scriptManager()->commandLineScripts();
-
     QHash<QString, QMenu *> menus;
+    const auto scripts = KTextEditor::EditorPrivate::self()->scriptManager()->commandLineScripts();
+    for (KateCommandLineScript *script : scripts) {
+        // traverse actions
+        const auto &actions = script->commandHeader().actions();
+        for (const auto &value : actions) {
+            // action is a value
+            const auto action = value.toObject();
+
+            // get command
+            const QString cmd = action.value(QStringLiteral("function")).toString();
 
-    foreach (KateCommandLineScript *script, scripts) {
-        /**
-         * traverse actions
-         */
-        const QJsonArray &actions = script->commandHeader().actions();
-        Q_FOREACH (const QJsonValue value, actions) {
-            /**
-             * action is a value
-             */
-            const QJsonObject action = value.toObject();
-            
-            /**
-             * get command
-             */
-            const QString cmd = action.value(QLatin1String("function")).toString();
-            
             // show in a category submenu?
             QMenu *m = menu();
-            QString category = action.value(QLatin1String("category")).toString();
+            QString category = action.value(QStringLiteral("category")).toString();
             if (!category.isEmpty()) {
                 category = i18nc("Script command category", category.toUtf8().data());
                 m = menus[category];
@@ -145,11 +122,11 @@ void KateScriptActionMenu::repopulate()
             QAction *a = new KateScriptAction(cmd, action, m_view);
             m->addAction(a);
             m_view->actionCollection()->addAction(QLatin1String("tools_scripts_") + cmd, a);
-            const QString shortcut = action.value(QLatin1String("shortcut")).toString();
+            const QString shortcut = action.value(QStringLiteral("shortcut")).toString();
             if (!shortcut.isEmpty()) {
                 m_view->actionCollection()->setDefaultShortcut(a, shortcut);
             }
-            
+
             m_actions.append(a);
         }
     }
@@ -160,5 +137,4 @@ void KateScriptActionMenu::repopulate()
     }
 }
 
-//END KateScriptActionMenu
-
+// END KateScriptActionMenu
