@@ -1,41 +1,23 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
+    SPDX-FileCopyrightText: 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2003, 2004 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2003 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2001, 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-    Copyright (C) 2007 Mirko Stocker <me@misto.ch>
-    Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
-    Copyright (C) 2003, 2004 Anders Lund <anders@alweb.dk>
-    Copyright (C) 2003 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2001,2002 Joseph Wenninger <jowenn@kde.org>
-    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // BEGIN INCLUDES
 #include "katehighlight.h"
 
 #include "kateconfig.h"
-#include "katedefaultcolors.h"
 #include "katedocument.h"
-#include "kateextendedattribute.h"
 #include "kateglobal.h"
 #include "katepartdebug.h"
 #include "katerenderer.h"
-#include "kateschema.h"
-#include "katetextline.h"
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -44,69 +26,22 @@
 #include <QAction>
 #include <QApplication>
 #include <QSet>
-#include <QStringList>
 #include <QTextStream>
 #include <QVarLengthArray>
 // END
 
-// BEGIN STATICS
-namespace
-{
-/**
- * convert from KSyntaxHighlighting => KTextEditor type
- * special handle non-1:1 things
- */
-inline KTextEditor::DefaultStyle textStyleToDefaultStyle(const KSyntaxHighlighting::Theme::TextStyle textStyle)
-{
-    // handle deviations
-    if (textStyle == KSyntaxHighlighting::Theme::Error) {
-        return KTextEditor::dsError;
-    }
-    if (textStyle == KSyntaxHighlighting::Theme::Others) {
-        return KTextEditor::dsOthers;
-    }
-
-    // else: simple cast
-    return static_cast<KTextEditor::DefaultStyle>(textStyle);
-}
-
-/**
- * convert the theme/schema name from KTextEditor => KSyntaxHighlighting.
- * NOTE: some themes of KTextEditor don't exist in KSyntaxHighlighting
- */
-inline QString convertThemeName(const QString &schema)
-{
-    if (schema == QLatin1String("Normal")) {
-        return QStringLiteral("Default");
-    } else if (schema == QLatin1String("Solarized (light)")) {
-        return QStringLiteral("Solarized Light");
-    } else if (schema == QLatin1String("Solarized (dark)")) {
-        return QStringLiteral("Solarized Dark");
-    }
-    return schema;
-}
-
-}
-// END
-
 // BEGIN KateHighlighting
 KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
 {
-    /**
-     * get name and section, always works
-     */
+    // get name and section, always works
     iName = def.name();
     iSection = def.translatedSection();
 
-    /**
-     * get all included definitions, e.g. PHP for HTML highlighting
-     */
+    // get all included definitions, e.g. PHP for HTML highlighting
     auto definitions = def.includedDefinitions();
 
-    /**
-     * handle the "no highlighting" case
-     * it's possible to not have any definitions with malformed file
-     */
+    // handle the "no highlighting" case
+    // it's possible to not have any definitions with malformed file
     if (!def.isValid() || (definitions.isEmpty() && def.formats().isEmpty())) {
         // dummy properties + formats
         m_properties.resize(1);
@@ -118,9 +53,7 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
         return;
     }
 
-    /**
-     * handle the real highlighting case
-     */
+    // handle the real highlighting case
     noHl = false;
     iHidden = def.isHidden();
     identifier = def.filePath();
@@ -129,28 +62,22 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
     folding = def.foldingEnabled();
     m_foldingIndentationSensitive = def.indentationBasedFoldingEnabled();
 
-    /**
-     * tell the AbstractHighlighter the definition it shall use
-     */
+    // tell the AbstractHighlighter the definition it shall use
     setDefinition(def);
 
-    /**
-     * first: handle only really included definitions
-     */
+    // first: handle only really included definitions
     for (const auto &includedDefinition : definitions)
         embeddedHighlightingModes.push_back(includedDefinition.name());
 
-    /**
-     * now: handle all, including this definition itself
-     * create the format => attributes mapping
-     * collect embedded highlightings, too
-     *
-     * we start with our definition as we want to have the default format
-     * of the initial definition as attribute with index == 0
-     *
-     * we collect additional properties in the m_properties and
-     * map the formats to the right properties in m_propertiesForFormat
-     */
+    // now: handle all, including this definition itself
+    // create the format => attributes mapping
+    // collect embedded highlightings, too
+    //
+    // we start with our definition as we want to have the default format
+    // of the initial definition as attribute with index == 0
+    //
+    // we collect additional properties in the m_properties and
+    // map the formats to the right properties in m_propertiesForFormat
     definitions.push_front(definition());
     m_properties.resize(definitions.size());
     size_t propertiesIndex = 0;
@@ -207,53 +134,37 @@ void KateHighlighting::doHighlight(const Kate::TextLineData *prevLine, Kate::Tex
         return;
     }
 
-    /**
-     * ensure we arrive in clean state
-     */
+    // ensure we arrive in clean state
     Q_ASSERT(!m_textLineToHighlight);
     Q_ASSERT(m_foldingStartToCount.isEmpty());
 
-    /**
-     * highlight the given line via the abstract highlighter
-     * a bit ugly: we set the line to highlight as member to be able to update its stats in the applyFormat and applyFolding member functions
-     */
+    // highlight the given line via the abstract highlighter
+    // a bit ugly: we set the line to highlight as member to be able to update its stats in the applyFormat and applyFolding member functions
     m_textLineToHighlight = textLine;
     const KSyntaxHighlighting::State initialState(!prevLine ? KSyntaxHighlighting::State() : prevLine->highlightingState());
     const KSyntaxHighlighting::State endOfLineState = highlightLine(textLine->string(), initialState);
     m_textLineToHighlight = nullptr;
 
-    /**
-     * update highlighting state if needed
-     */
+    // update highlighting state if needed
     if (textLine->highlightingState() != endOfLineState) {
         textLine->setHighlightingState(endOfLineState);
         ctxChanged = true;
     }
 
-    /**
-     * handle folding info computed and cleanup hash again, if there
-     * check if folding is not balanced and we have more starts then ends
-     * then this line is a possible folding start!
-     */
+    // handle folding info computed and cleanup hash again, if there
+    // check if folding is not balanced and we have more starts then ends
+    // then this line is a possible folding start!
     if (!m_foldingStartToCount.isEmpty()) {
-        /**
-         * possible folding start, if imbalanced, aka hash not empty!
-         */
+        // possible folding start, if imbalanced, aka hash not empty!
         textLine->markAsFoldingStartAttribute();
 
-        /**
-         * clear hash for next doHighlight
-         */
+        // clear hash for next doHighlight
         m_foldingStartToCount.clear();
     }
 
-    /**
-     * check for indentation based folding
-     */
+    // check for indentation based folding
     if (m_foldingIndentationSensitive && (tabWidth > 0) && !textLine->markedAsFoldingStartAttribute()) {
-        /**
-         * compute if we increase indentation in next line
-         */
+        // compute if we increase indentation in next line
         if (endOfLineState.indentationBasedFoldingEnabled() && !isEmptyLine(textLine) && !isEmptyLine(nextLine) && (textLine->indentDepth(tabWidth) < nextLine->indentDepth(tabWidth))) {
             textLine->markAsFoldingStartIndentation();
         }
@@ -284,9 +195,7 @@ void KateHighlighting::applyFolding(int offset, int length, KSyntaxHighlighting:
     const int foldingValue = (region.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? int(region.id()) : -int(region.id());
     m_textLineToHighlight->addFolding(offset + ((region.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? 0 : length), foldingValue);
 
-    /**
-     * for each end region, decrement counter for that type, erase if count reaches 0!
-     */
+    // for each end region, decrement counter for that type, erase if count reaches 0!
     if (foldingValue < 0) {
         QHash<int, int>::iterator end = m_foldingStartToCount.find(-foldingValue);
         if (end != m_foldingStartToCount.end()) {
@@ -298,131 +207,12 @@ void KateHighlighting::applyFolding(int offset, int length, KSyntaxHighlighting:
         }
     }
 
-    /**
-     * increment counter for each begin region!
-     */
+    // increment counter for each begin region!
     if (foldingValue > 0) {
         ++m_foldingStartToCount[foldingValue];
     }
 }
 
-void KateHighlighting::getKateExtendedAttributeList(const QString &schema, QVector<KTextEditor::Attribute::Ptr> &list, KConfig *cfg)
-{
-    KConfigGroup config(cfg ? cfg : KateHlManager::self()->getKConfig(), QLatin1String("Highlighting ") + iName + QLatin1String(" - Schema ") + schema);
-
-    list = attributesForDefinition(schema);
-    for (auto &p : qAsConst(list)) {
-        QStringList s = config.readEntry(p->name(), QStringList());
-
-        //    qCDebug(LOG_KTE)<<p->name<<s.count();
-        if (!s.isEmpty()) {
-            while (s.count() < 10) {
-                s << QString();
-            }
-            QString name = p->name();
-            bool spellCheck = !p->skipSpellChecking();
-            p->clear();
-            p->setName(name);
-            p->setSkipSpellChecking(!spellCheck);
-
-            QString tmp = s[0];
-            if (!tmp.isEmpty()) {
-                p->setDefaultStyle(static_cast<KTextEditor::DefaultStyle>(tmp.toInt()));
-            }
-
-            QRgb col;
-
-            tmp = s[1];
-            if (!tmp.isEmpty()) {
-                col = tmp.toUInt(nullptr, 16);
-                p->setForeground(QColor(col));
-            }
-
-            tmp = s[2];
-            if (!tmp.isEmpty()) {
-                col = tmp.toUInt(nullptr, 16);
-                p->setSelectedForeground(QColor(col));
-            }
-
-            tmp = s[3];
-            if (!tmp.isEmpty()) {
-                p->setFontBold(tmp != QLatin1String("0"));
-            }
-
-            tmp = s[4];
-            if (!tmp.isEmpty()) {
-                p->setFontItalic(tmp != QLatin1String("0"));
-            }
-
-            tmp = s[5];
-            if (!tmp.isEmpty()) {
-                p->setFontStrikeOut(tmp != QLatin1String("0"));
-            }
-
-            tmp = s[6];
-            if (!tmp.isEmpty()) {
-                p->setFontUnderline(tmp != QLatin1String("0"));
-            }
-
-            tmp = s[7];
-            if (!tmp.isEmpty()) {
-                col = tmp.toUInt(nullptr, 16);
-                p->setBackground(QColor(col));
-            }
-
-            tmp = s[8];
-            if (!tmp.isEmpty()) {
-                col = tmp.toUInt(nullptr, 16);
-                p->setSelectedBackground(QColor(col));
-            }
-
-            tmp = s[9];
-            if (!tmp.isEmpty() && tmp != QLatin1String("---")) {
-                p->setFontFamily(tmp);
-            }
-        }
-    }
-}
-
-void KateHighlighting::getKateExtendedAttributeListCopy(const QString &schema, QVector<KTextEditor::Attribute::Ptr> &list, KConfig *cfg)
-{
-    QVector<KTextEditor::Attribute::Ptr> attributes;
-    getKateExtendedAttributeList(schema, attributes, cfg);
-
-    list.clear();
-
-    for (const KTextEditor::Attribute::Ptr &attribute : qAsConst(attributes)) {
-        list.append(KTextEditor::Attribute::Ptr(new KTextEditor::Attribute(*attribute.data())));
-    }
-}
-
-void KateHighlighting::setKateExtendedAttributeList(const QString &schema, QVector<KTextEditor::Attribute::Ptr> &list, KConfig *cfg, bool writeDefaultsToo)
-{
-    KConfigGroup config(cfg ? cfg : KateHlManager::self()->getKConfig(), QLatin1String("Highlighting ") + iName + QLatin1String(" - Schema ") + schema);
-
-    KateAttributeList defList;
-    KateHlManager::self()->getDefaults(schema, defList);
-    for (auto &p : qAsConst(list)) {
-        QStringList settings;
-        KTextEditor::DefaultStyle defStyle = p->defaultStyle();
-        KTextEditor::Attribute::Ptr a(defList[defStyle]);
-        settings << QString::number(p->defaultStyle(), 10);
-        settings << (p->hasProperty(QTextFormat::ForegroundBrush) ? QString::number(p->foreground().color().rgb(), 16) : (writeDefaultsToo ? QString::number(a->foreground().color().rgb(), 16) : QString()));
-        settings << (p->hasProperty(SelectedForeground) ? QString::number(p->selectedForeground().color().rgb(), 16) : (writeDefaultsToo ? QString::number(a->selectedForeground().color().rgb(), 16) : QString()));
-        settings << (p->hasProperty(QTextFormat::FontWeight) ? (p->fontBold() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontBold() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
-        settings << (p->hasProperty(QTextFormat::FontItalic) ? (p->fontItalic() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontItalic() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
-        settings << (p->hasProperty(QTextFormat::FontStrikeOut) ? (p->fontStrikeOut() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontStrikeOut() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
-        settings << (p->hasProperty(QTextFormat::TextUnderlineStyle) ? (p->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
-        settings << (p->hasProperty(QTextFormat::BackgroundBrush) ? QString::number(p->background().color().rgb(), 16)
-                                                                  : ((writeDefaultsToo && a->hasProperty(QTextFormat::BackgroundBrush)) ? QString::number(a->background().color().rgb(), 16) : QString()));
-        settings << (p->hasProperty(SelectedBackground) ? QString::number(p->selectedBackground().color().rgb(), 16)
-                                                        : ((writeDefaultsToo && a->hasProperty(SelectedBackground)) ? QString::number(a->selectedBackground().color().rgb(), 16) : QString()));
-        settings << (p->hasProperty(QTextFormat::FontFamily) ? (p->fontFamily()) : (writeDefaultsToo ? a->fontFamily() : QString()));
-        settings << QStringLiteral("---");
-        config.writeEntry(p->name(), settings);
-    }
-}
-
 int KateHighlighting::sanitizeFormatIndex(int attrib) const
 {
     // sanitize, e.g. one could have old hl info with now invalid attribs
@@ -516,85 +306,40 @@ void KateHighlighting::clearAttributeArrays()
     m_attributeArrays.clear();
 }
 
-QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(const QString &schema)
+QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(const QString &schema) const
 {
-    /**
-     * get the KSyntaxHighlighting theme from the chosen schema.
-     * NOTE: if the theme isn't valid for KSyntaxHighlighting, an empty/invalid theme will be used.
-     * For example, the "KDE" and "Vim (dark)" themes don't exist in KSyntaxHighlighting.
-     */
-    KSyntaxHighlighting::Theme currentTheme = KateHlManager::self()->repository().theme(convertThemeName(schema));
-
-    /**
-     * create list of all known things
-     */
+    // create list of known attributes based on highlighting format & wanted theme
     QVector<KTextEditor::Attribute::Ptr> array;
+    const auto currentTheme = KateHlManager::self()->repository().theme(schema);
     for (const auto &format : m_formats) {
-        /**
-         * atm we just set the current chosen theme here for later color generation
-         */
-        setTheme(currentTheme);
-
-        /**
-         * create a KTextEditor attribute matching the given format
-         */
+        // create a KTextEditor attribute matching the given format
         KTextEditor::Attribute::Ptr newAttribute(new KTextEditor::Attribute(nameForAttrib(array.size()), textStyleToDefaultStyle(format.textStyle())));
 
-        /**
-         * NOTE: if "theme()" returns an empty/invalid theme, only the
-         * attribute styles set in the XML files will be applied here.
-         */
-        if (format.hasTextColor(theme())) {
-            newAttribute->setForeground(format.textColor(theme()));
-            newAttribute->setSelectedForeground(format.selectedTextColor(theme()));
+        if (const auto color = format.textColor(currentTheme).rgba()) {
+            newAttribute->setForeground(QColor(color));
         }
 
-        if (format.hasBackgroundColor(theme())) {
-            newAttribute->setBackground(format.backgroundColor(theme()));
-            newAttribute->setSelectedBackground(format.selectedBackgroundColor(theme()));
+        if (const auto color = format.selectedTextColor(currentTheme).rgba()) {
+            newAttribute->setSelectedForeground(QColor(color));
         }
 
-        /**
-         * Apply attributes set in the syntax definition XML files.
-         * This overwrites the default theme and the theme customized by the user.
-         *
-         * It's allowed to turn off the bold, italic, underline and strikeout
-         * attributes in the XML files (see bug #143399).
-         */
-        if (format.hasBoldOverride()) {
-            if (format.isBold(theme())) {
-                newAttribute->setFontBold(true);
-            } else {
-                newAttribute->setFontBold(false);
-            }
+        if (const auto color = format.backgroundColor(currentTheme).rgba()) {
+            newAttribute->setBackground(QColor(color));
+        } else {
+            newAttribute->clearBackground();
         }
 
-        if (format.hasItalicOverride()) {
-            if (format.isItalic(theme())) {
-                newAttribute->setFontItalic(true);
-            } else {
-                newAttribute->setFontItalic(false);
-            }
-        }
-
-        if (format.hasUnderlineOverride()) {
-            if (format.isUnderline(theme())) {
-                newAttribute->setFontUnderline(true);
-            } else {
-                newAttribute->setFontUnderline(false);
-            }
-        }
-
-        if (format.hasStrikeThroughOverride()) {
-            if (format.isStrikeThrough(theme())) {
-                newAttribute->setFontStrikeOut(true);
-            } else {
-                newAttribute->setFontStrikeOut(false);
-            }
+        if (const auto color = format.selectedBackgroundColor(currentTheme).rgba()) {
+            newAttribute->setSelectedBackground(QColor(color));
+        } else {
+            newAttribute->clearProperty(SelectedBackground);
         }
 
+        newAttribute->setFontBold(format.isBold(currentTheme));
+        newAttribute->setFontItalic(format.isItalic(currentTheme));
+        newAttribute->setFontUnderline(format.isUnderline(currentTheme));
+        newAttribute->setFontStrikeOut(format.isStrikeThrough(currentTheme));
         newAttribute->setSkipSpellChecking(format.spellCheck());
-
         array.append(newAttribute);
     }
     return array;
@@ -602,34 +347,14 @@ QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(c
 
 QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributes(const QString &schema)
 {
-    // found it, already floating around
+    // query cache first
     if (m_attributeArrays.contains(schema)) {
         return m_attributeArrays[schema];
     }
 
-    // k, schema correct, let create the data
-    QVector<KTextEditor::Attribute::Ptr> array;
-    KateAttributeList defaultStyleList;
-
-    KateHlManager::self()->getDefaults(schema, defaultStyleList);
-
-    QVector<KTextEditor::Attribute::Ptr> itemDataList;
-    getKateExtendedAttributeList(schema, itemDataList);
-
-    uint nAttribs = itemDataList.count();
-    for (uint z = 0; z < nAttribs; z++) {
-        KTextEditor::Attribute::Ptr itemData = itemDataList.at(z);
-        KTextEditor::Attribute::Ptr newAttribute(new KTextEditor::Attribute(*defaultStyleList.at(itemData->defaultStyle())));
-
-        if (itemData && itemData->hasAnyProperty()) {
-            *newAttribute += *itemData;
-        }
-
-        array.append(newAttribute);
-    }
-
+    // create new attributes array for wanted theme and cache it
+    const auto array = attributesForDefinition(schema);
     m_attributeArrays.insert(schema, array);
-
     return array;
 }
 
@@ -675,9 +400,7 @@ int KateHighlighting::attributeForLocation(KTextEditor::DocumentPrivate *doc, co
         return 0;
     }
 
-    /**
-     * either get char attribute or attribute of context still active at end of line
-     */
+    // either get char attribute or attribute of context still active at end of line
     if (cursor.column() < tl->length()) {
         return sanitizeFormatIndex(tl->attribute(cursor.column()));
     } else if (cursor.column() >= tl->length()) {
